@@ -5,11 +5,11 @@
 /* E-mail : ladik@zezula.net                                                 */
 /* WWW    : www.zezula.net                                                   */
 /*---------------------------------------------------------------------------*/
-/*                       Archive functions of Storm.dll                      */
+/* Implementation of archive functions                                       */
 /*---------------------------------------------------------------------------*/
 /*   Date    Ver   Who  Comment                                              */
 /* --------  ----  ---  -------                                              */
-/* xx.xx.xx  1.00  Lad  The first version of SFileOpenArchive.cpp            */
+/* xx.xx.xx  1.00  Lad  Created                                              */
 /* 19.11.03  1.01  Dan  Big endian handling                                  */
 /*****************************************************************************/
 
@@ -19,26 +19,53 @@
 
 #define HEADER_SEARCH_BUFFER_SIZE   0x1000
 
-/*****************************************************************************/
-/* Local functions                                                           */
-/*****************************************************************************/
+//-----------------------------------------------------------------------------
+// Local functions
 
-static bool IsAviFile(DWORD * HeaderData)
+static MTYPE CheckMapType(LPCTSTR szFileName, LPBYTE pbHeaderBuffer, size_t cbHeaderBuffer)
 {
-    DWORD DwordValue0 = BSWAP_INT32_UNSIGNED(HeaderData[0]);
-    DWORD DwordValue2 = BSWAP_INT32_UNSIGNED(HeaderData[2]);
-    DWORD DwordValue3 = BSWAP_INT32_UNSIGNED(HeaderData[3]);
+    LPDWORD HeaderInt32 = (LPDWORD)pbHeaderBuffer;
+    LPCTSTR szExtension;
 
-    // Test for 'RIFF', 'AVI ' or 'LIST'
-    return (DwordValue0 == 0x46464952 && DwordValue2 == 0x20495641 && DwordValue3 == 0x5453494C);
-}
+    // Don't do any checks if there is not at least 16 bytes
+    if(cbHeaderBuffer > 0x10)
+    {
+        DWORD DwordValue0 = BSWAP_INT32_UNSIGNED(HeaderInt32[0]);
+        DWORD DwordValue1 = BSWAP_INT32_UNSIGNED(HeaderInt32[1]);
+        DWORD DwordValue2 = BSWAP_INT32_UNSIGNED(HeaderInt32[2]);
+        DWORD DwordValue3 = BSWAP_INT32_UNSIGNED(HeaderInt32[3]);
 
-static bool IsWarcraft3Map(DWORD * HeaderData)
-{
-    DWORD DwordValue0 = BSWAP_INT32_UNSIGNED(HeaderData[0]);
-    DWORD DwordValue1 = BSWAP_INT32_UNSIGNED(HeaderData[1]);
+        // Test for AVI files (Warcraft III cinematics) - 'RIFF', 'AVI ' or 'LIST'
+        if(DwordValue0 == 0x46464952 && DwordValue2 == 0x20495641 && DwordValue3 == 0x5453494C)
+            return MapTypeAviFile;
 
-    return (DwordValue0 == 0x57334D48 && DwordValue1 == 0x00000000);
+        // Check for Starcraft II maps
+        if((szExtension = _tcsrchr(szFileName, _T('.'))) != NULL)
+        {
+            // The "NP_Protect" protector places fake Warcraft III header
+            // into the Starcraft II maps, whilst SC2 maps have no other header but MPQ v4
+            if(!_tcsicmp(szExtension, _T(".s2ma")) || !_tcsicmp(szExtension, _T(".SC2Map")) || !_tcsicmp(szExtension, _T(".SC2Mod")))
+            {
+                return MapTypeStarcraft2;
+            }
+        }
+
+        // Check for Warcraft III maps
+        if(DwordValue0 == 0x57334D48 && DwordValue1 == 0x00000000)
+            return MapTypeWarcraft3;
+    }
+
+    // MIX files are DLL files that contain MPQ in overlay.
+    // Only Warcraft III is able to load them, so we consider them Warcraft III maps
+    if(cbHeaderBuffer > 0x200 && pbHeaderBuffer[0] == 'M' && pbHeaderBuffer[1] == 'Z')
+    {
+        // Check the value of IMAGE_DOS_HEADER::e_lfanew at offset 0x3C
+        if(0 < HeaderInt32[0x0F] && HeaderInt32[0x0F] < 0x10000)
+            return MapTypeWarcraft3;
+    }
+
+    // No special map type recognized
+    return MapTypeNotRecognized;
 }
 
 static TMPQUserData * IsValidMpqUserData(ULONGLONG ByteOffset, ULONGLONG FileSize, void * pvUserData)
@@ -46,7 +73,7 @@ static TMPQUserData * IsValidMpqUserData(ULONGLONG ByteOffset, ULONGLONG FileSiz
     TMPQUserData * pUserData;
 
     // BSWAP the source data and copy them to our buffer
-    BSWAP_ARRAY32_UNSIGNED(&pvUserData, sizeof(TMPQUserData));
+    BSWAP_ARRAY32_UNSIGNED(pvUserData, sizeof(TMPQUserData));
     pUserData = (TMPQUserData *)pvUserData;
 
     // Check the sizes
@@ -69,10 +96,11 @@ static TMPQUserData * IsValidMpqUserData(ULONGLONG ByteOffset, ULONGLONG FileSiz
 }
 
 // This function gets the right positions of the hash table and the block table.
-static int VerifyMpqTablePositions(TMPQArchive * ha, ULONGLONG FileSize)
+static DWORD VerifyMpqTablePositions(TMPQArchive * ha, ULONGLONG FileSize)
 {
     TMPQHeader * pHeader = ha->pHeader;
     ULONGLONG ByteOffset;
+    //bool bMalformed = (ha->dwFlags & MPQ_FLAG_MALFORMED) ? true : false;
 
     // Check the begin of HET table
     if(pHeader->HetTablePos64)
@@ -107,20 +135,49 @@ static int VerifyMpqTablePositions(TMPQArchive * ha, ULONGLONG FileSize)
     }
 
     // Check the begin of hi-block table
-    if(pHeader->HiBlockTablePos64 != 0)
-    {
-        ByteOffset = ha->MpqPos + pHeader->HiBlockTablePos64;
-        if(ByteOffset > FileSize)
-            return ERROR_BAD_FORMAT;
-    }
+    //if(pHeader->HiBlockTablePos64 != 0)
+    //{
+    //    ByteOffset = ha->MpqPos + pHeader->HiBlockTablePos64;
+    //    if(ByteOffset > FileSize)
+    //        return ERROR_BAD_FORMAT;
+    //}
 
     // All OK.
     return ERROR_SUCCESS;
 }
 
-/*****************************************************************************/
-/* Public functions                                                          */
-/*****************************************************************************/
+//-----------------------------------------------------------------------------
+// Support for alternate markers. Call before opening an archive
+
+#define SFILE_MARKERS_MIN_SIZE   (sizeof(DWORD) + sizeof(DWORD) + sizeof(const char *) + sizeof(const char *))
+
+bool WINAPI SFileSetArchiveMarkers(PSFILE_MARKERS pMarkers)
+{
+    // Check structure minimum size
+    if(pMarkers == NULL || pMarkers->dwSize < SFILE_MARKERS_MIN_SIZE)
+    {
+        SetLastError(ERROR_INVALID_PARAMETER);
+        return false;
+    }
+
+    // Make sure that the MPQ cryptography is initialized at this time
+    InitializeMpqCryptography();
+
+    // Remember the marker for MPQ header
+    if(pMarkers->dwSignature != 0)
+        g_dwMpqSignature = pMarkers->dwSignature;
+
+    // Remember the encryption key for hash table
+    if(pMarkers->szHashTableKey != NULL)
+        g_dwHashTableKey = HashString(pMarkers->szHashTableKey, MPQ_HASH_FILE_KEY);
+
+    // Remember the encryption key for block table
+    if(pMarkers->szBlockTableKey != NULL)
+        g_dwBlockTableKey = HashString(pMarkers->szBlockTableKey, MPQ_HASH_FILE_KEY);
+
+    // Succeeded
+    return true;
+}
 
 //-----------------------------------------------------------------------------
 // SFileGetLocale and SFileSetLocale
@@ -128,13 +185,13 @@ static int VerifyMpqTablePositions(TMPQArchive * ha, ULONGLONG FileSize)
 
 LCID WINAPI SFileGetLocale()
 {
-    return lcFileLocale;
+    return g_lcFileLocale;
 }
 
 LCID WINAPI SFileSetLocale(LCID lcNewLocale)
 {
-    lcFileLocale = lcNewLocale;
-    return lcFileLocale;
+    g_lcFileLocale = lcNewLocale;
+    return g_lcFileLocale;
 }
 
 //-----------------------------------------------------------------------------
@@ -158,8 +215,8 @@ bool WINAPI SFileOpenArchive(
     ULONGLONG FileSize = 0;             // Size of the file
     LPBYTE pbHeaderBuffer = NULL;       // Buffer for searching MPQ header
     DWORD dwStreamFlags = (dwFlags & STREAM_FLAGS_MASK);
-    bool bIsWarcraft3Map = false;
-    int nError = ERROR_SUCCESS;   
+    MTYPE MapType = MapTypeNotChecked;
+    DWORD dwErrCode = ERROR_SUCCESS;
 
     // Verify the parameters
     if(szMpqName == NULL || *szMpqName == 0 || phMpq == NULL)
@@ -181,32 +238,32 @@ bool WINAPI SFileOpenArchive(
         return false;
 
     // Check the file size. There must be at least 0x20 bytes
-    if(nError == ERROR_SUCCESS)
+    if(dwErrCode == ERROR_SUCCESS)
     {
         FileStream_GetSize(pStream, &FileSize);
         if(FileSize < MPQ_HEADER_SIZE_V1)
-            nError = ERROR_BAD_FORMAT;
+            dwErrCode = ERROR_BAD_FORMAT;
     }
 
     // Allocate the MPQhandle
-    if(nError == ERROR_SUCCESS)
+    if(dwErrCode == ERROR_SUCCESS)
     {
         if((ha = STORM_ALLOC(TMPQArchive, 1)) == NULL)
-            nError = ERROR_NOT_ENOUGH_MEMORY;
+            dwErrCode = ERROR_NOT_ENOUGH_MEMORY;
     }
 
     // Allocate buffer for searching MPQ header
-    if(nError == ERROR_SUCCESS)
+    if(dwErrCode == ERROR_SUCCESS)
     {
         pbHeaderBuffer = STORM_ALLOC(BYTE, HEADER_SEARCH_BUFFER_SIZE);
         if(pbHeaderBuffer == NULL)
-            nError = ERROR_NOT_ENOUGH_MEMORY;
+            dwErrCode = ERROR_NOT_ENOUGH_MEMORY;
     }
 
     // Find the position of MPQ header
-    if(nError == ERROR_SUCCESS)
+    if(dwErrCode == ERROR_SUCCESS)
     {
-        ULONGLONG SearchOffset = 0;
+        ULONGLONG ByteOffset = 0;
         ULONGLONG EndOfSearch = FileSize;
         DWORD dwStrmFlags = 0;
         DWORD dwHeaderSize;
@@ -227,44 +284,42 @@ bool WINAPI SFileOpenArchive(
 
         // Also remember if this MPQ is a patch
         ha->dwFlags |= (dwFlags & MPQ_OPEN_PATCH) ? MPQ_FLAG_PATCH : 0;
-       
+
         // Limit the header searching to about 130 MB of data
         if(EndOfSearch > 0x08000000)
             EndOfSearch = 0x08000000;
 
         // Find the offset of MPQ header within the file
-        while(bSearchComplete == false && SearchOffset < EndOfSearch)
+        while(bSearchComplete == false && ByteOffset < EndOfSearch)
         {
             // Always read at least 0x1000 bytes for performance.
             // This is what Storm.dll (2002) does.
             DWORD dwBytesAvailable = HEADER_SEARCH_BUFFER_SIZE;
-            DWORD dwInBufferOffset = 0;
 
             // Cut the bytes available, if needed
-            if((FileSize - SearchOffset) < HEADER_SEARCH_BUFFER_SIZE)
-                dwBytesAvailable = (DWORD)(FileSize - SearchOffset);
+            if((FileSize - ByteOffset) < HEADER_SEARCH_BUFFER_SIZE)
+                dwBytesAvailable = (DWORD)(FileSize - ByteOffset);
 
             // Read the eventual MPQ header
-            if(!FileStream_Read(ha->pStream, &SearchOffset, pbHeaderBuffer, dwBytesAvailable))
+            if(!FileStream_Read(ha->pStream, &ByteOffset, pbHeaderBuffer, dwBytesAvailable))
             {
-                nError = GetLastError();
+                dwErrCode = GetLastError();
                 break;
             }
 
-            // There are AVI files from Warcraft III with 'MPQ' extension.
-            if(SearchOffset == 0)
+            // Check whether the file is AVI file or a Warcraft III/Starcraft II map
+            if(MapType == MapTypeNotChecked)
             {
-                if(IsAviFile((DWORD *)pbHeaderBuffer))
+                // Do nothing if the file is an AVI file
+                if((MapType = CheckMapType(szMpqName, pbHeaderBuffer, dwBytesAvailable)) == MapTypeAviFile)
                 {
-                    nError = ERROR_AVI_FILE;
+                    dwErrCode = ERROR_AVI_FILE;
                     break;
                 }
-
-                bIsWarcraft3Map = IsWarcraft3Map((DWORD *)pbHeaderBuffer);
             }
 
             // Search the header buffer
-            while(dwInBufferOffset < dwBytesAvailable)
+            for(DWORD dwInBufferOffset = 0; dwInBufferOffset < dwBytesAvailable; dwInBufferOffset += 0x200)
             {
                 // Copy the data from the potential header buffer to the MPQ header
                 memcpy(ha->HeaderData, pbHeaderBuffer + dwInBufferOffset, sizeof(ha->HeaderData));
@@ -272,21 +327,21 @@ bool WINAPI SFileOpenArchive(
                 // If there is the MPQ user data, process it
                 // Note that Warcraft III does not check for user data, which is abused by many map protectors
                 dwHeaderID = BSWAP_INT32_UNSIGNED(ha->HeaderData[0]);
-                if(bIsWarcraft3Map == false && (dwFlags & MPQ_OPEN_FORCE_MPQ_V1) == 0)
+                if(MapType != MapTypeWarcraft3 && (dwFlags & MPQ_OPEN_FORCE_MPQ_V1) == 0)
                 {
                     if(ha->pUserData == NULL && dwHeaderID == ID_MPQ_USERDATA)
                     {
                         // Verify if this looks like a valid user data
-                        pUserData = IsValidMpqUserData(SearchOffset, FileSize, ha->HeaderData);
+                        pUserData = IsValidMpqUserData(ByteOffset, FileSize, ha->HeaderData);
                         if(pUserData != NULL)
                         {
                             // Fill the user data header
-                            ha->UserDataPos = SearchOffset;
+                            ha->UserDataPos = ByteOffset;
                             ha->pUserData = &ha->UserData;
                             memcpy(ha->pUserData, pUserData, sizeof(TMPQUserData));
 
                             // Continue searching from that position
-                            SearchOffset += ha->pUserData->dwHeaderOffs;
+                            ByteOffset += ha->pUserData->dwHeaderOffs;
                             break;
                         }
                     }
@@ -297,19 +352,22 @@ bool WINAPI SFileOpenArchive(
                 // Abused by Spazzler Map protector. Note that the size check is not present
                 // in Storm.dll v 1.00, so Diablo I code would load the MPQ anyway.
                 dwHeaderSize = BSWAP_INT32_UNSIGNED(ha->HeaderData[1]);
-                if(dwHeaderID == ID_MPQ && dwHeaderSize >= MPQ_HEADER_SIZE_V1)
+                if(dwHeaderID == g_dwMpqSignature && dwHeaderSize >= MPQ_HEADER_SIZE_V1)
                 {
                     // Now convert the header to version 4
-                    nError = ConvertMpqHeaderToFormat4(ha, SearchOffset, FileSize, dwFlags, bIsWarcraft3Map);
-                    bSearchComplete = true;
-                    break;
+                    dwErrCode = ConvertMpqHeaderToFormat4(ha, ByteOffset, FileSize, dwFlags, MapType);
+                    if(dwErrCode != ERROR_FAKE_MPQ_HEADER)
+                    {
+                        bSearchComplete = true;
+                        break;
+                    }
                 }
 
                 // Check for MPK archives (Longwu Online - MPQ fork)
-                if(bIsWarcraft3Map == false && dwHeaderID == ID_MPK)
+                if(MapType == MapTypeNotRecognized && dwHeaderID == ID_MPK)
                 {
                     // Now convert the MPK header to MPQ Header version 4
-                    nError = ConvertMpkHeaderToFormat4(ha, FileSize, dwFlags);
+                    dwErrCode = ConvertMpkHeaderToFormat4(ha, FileSize, dwFlags);
                     bSearchComplete = true;
                     break;
                 }
@@ -317,37 +375,36 @@ bool WINAPI SFileOpenArchive(
                 // If searching for the MPQ header is disabled, return an error
                 if(dwFlags & MPQ_OPEN_NO_HEADER_SEARCH)
                 {
-                    nError = ERROR_NOT_SUPPORTED;
+                    dwErrCode = ERROR_NOT_SUPPORTED;
                     bSearchComplete = true;
                     break;
                 }
 
                 // Move the pointers
-                SearchOffset += 0x200;
-                dwInBufferOffset += 0x200;
+                ByteOffset += 0x200;
             }
         }
 
         // Did we identify one of the supported headers?
-        if(nError == ERROR_SUCCESS)
+        if(dwErrCode == ERROR_SUCCESS)
         {
             // Set the user data position to the MPQ header, if none
             if(ha->pUserData == NULL)
-                ha->UserDataPos = SearchOffset;
+                ha->UserDataPos = ByteOffset;
 
             // Set the position of the MPQ header
             ha->pHeader  = (TMPQHeader *)ha->HeaderData;
-            ha->MpqPos   = SearchOffset;
+            ha->MpqPos   = ByteOffset;
             ha->FileSize = FileSize;
 
             // Sector size must be nonzero.
-            if(SearchOffset >= FileSize || ha->pHeader->wSectorSize == 0)
-                nError = ERROR_BAD_FORMAT;
+            if(ByteOffset >= FileSize || ha->pHeader->wSectorSize == 0)
+                dwErrCode = ERROR_BAD_FORMAT;
         }
     }
 
     // Fix table positions according to format
-    if(nError == ERROR_SUCCESS)
+    if(dwErrCode == ERROR_SUCCESS)
     {
         // Dump the header
 //      DumpMpqHeader(ha->pHeader);
@@ -380,32 +437,32 @@ bool WINAPI SFileOpenArchive(
             ha->dwFlags |= MPQ_FLAG_LISTFILE_FORCE;
 
         // Remember whether whis is a map for Warcraft III
-        if(bIsWarcraft3Map)
+        if(MapType == MapTypeWarcraft3)
             ha->dwFlags |= MPQ_FLAG_WAR3_MAP;
 
         // Set the size of file sector
         ha->dwSectorSize = (0x200 << ha->pHeader->wSectorSize);
 
         // Verify if any of the tables doesn't start beyond the end of the file
-        nError = VerifyMpqTablePositions(ha, FileSize);
+        dwErrCode = VerifyMpqTablePositions(ha, FileSize);
     }
 
     // Read the hash table. Ignore the result, as hash table is no longer required
     // Read HET table. Ignore the result, as HET table is no longer required
-    if(nError == ERROR_SUCCESS)
+    if(dwErrCode == ERROR_SUCCESS)
     {
-        nError = LoadAnyHashTable(ha);
+        dwErrCode = LoadAnyHashTable(ha);
     }
 
     // Now, build the file table. It will be built by combining
     // the block table, BET table, hi-block table, (attributes) and (listfile).
-    if(nError == ERROR_SUCCESS)
+    if(dwErrCode == ERROR_SUCCESS)
     {
-        nError = BuildFileTable(ha);
+        dwErrCode = BuildFileTable(ha);
     }
 
     // Load the internal listfile and include it to the file table
-    if(nError == ERROR_SUCCESS && (dwFlags & MPQ_OPEN_NO_LISTFILE) == 0)
+    if(dwErrCode == ERROR_SUCCESS && (dwFlags & MPQ_OPEN_NO_LISTFILE) == 0)
     {
         // Quick check for (listfile)
         pFileEntry = GetFileEntryLocale(ha, LISTFILE_NAME, LANG_NEUTRAL);
@@ -418,7 +475,7 @@ bool WINAPI SFileOpenArchive(
     }
 
     // Load the "(attributes)" file and merge it to the file table
-    if(nError == ERROR_SUCCESS && (dwFlags & MPQ_OPEN_NO_ATTRIBUTES) == 0 && (ha->dwFlags & MPQ_FLAG_BLOCK_TABLE_CUT) == 0)
+    if(dwErrCode == ERROR_SUCCESS && (dwFlags & MPQ_OPEN_NO_ATTRIBUTES) == 0 && (ha->dwFlags & MPQ_FLAG_BLOCK_TABLE_CUT) == 0)
     {
         // Quick check for (attributes)
         pFileEntry = GetFileEntryLocale(ha, ATTRIBUTES_NAME, LANG_NEUTRAL);
@@ -431,7 +488,7 @@ bool WINAPI SFileOpenArchive(
     }
 
     // Remember whether the archive has weak signature. Only for MPQs format 1.0.
-    if(nError == ERROR_SUCCESS)
+    if(dwErrCode == ERROR_SUCCESS)
     {
         // Quick check for (signature)
         pFileEntry = GetFileEntryLocale(ha, SIGNATURE_NAME, LANG_NEUTRAL);
@@ -447,11 +504,11 @@ bool WINAPI SFileOpenArchive(
     }
 
     // Cleanup and exit
-    if(nError != ERROR_SUCCESS)
+    if(dwErrCode != ERROR_SUCCESS)
     {
         FileStream_Close(pStream);
         FreeArchiveHandle(ha);
-        SetLastError(nError);
+        SetLastError(dwErrCode);
         ha = NULL;
     }
 
@@ -460,7 +517,7 @@ bool WINAPI SFileOpenArchive(
         STORM_FREE(pbHeaderBuffer);
     if(phMpq != NULL)
         *phMpq = ha;
-    return (nError == ERROR_SUCCESS);
+    return (dwErrCode == ERROR_SUCCESS);
 }
 
 //-----------------------------------------------------------------------------
@@ -495,8 +552,8 @@ bool WINAPI SFileSetDownloadCallback(HANDLE hMpq, SFILE_DOWNLOAD_CALLBACK Downlo
 bool WINAPI SFileFlushArchive(HANDLE hMpq)
 {
     TMPQArchive * ha;
-    int nResultError = ERROR_SUCCESS;
-    int nError;
+    DWORD dwResultError = ERROR_SUCCESS;
+    DWORD dwErrCode;
 
     // Do nothing if 'hMpq' is bad parameter
     if((ha = IsValidMpqHandle(hMpq)) == NULL)
@@ -521,23 +578,23 @@ bool WINAPI SFileFlushArchive(HANDLE hMpq)
 
         if(ha->dwFlags & MPQ_FLAG_SIGNATURE_NEW)
         {
-            nError = SSignFileCreate(ha);
-            if(nError != ERROR_SUCCESS)
-                nResultError = nError;
+            dwErrCode = SSignFileCreate(ha);
+            if(dwErrCode != ERROR_SUCCESS)
+                dwResultError = dwErrCode;
         }
 
         if(ha->dwFlags & (MPQ_FLAG_LISTFILE_NEW | MPQ_FLAG_LISTFILE_FORCE))
         {
-            nError = SListFileSaveToMpq(ha);
-            if(nError != ERROR_SUCCESS)
-                nResultError = nError;
+            dwErrCode = SListFileSaveToMpq(ha);
+            if(dwErrCode != ERROR_SUCCESS)
+                dwResultError = dwErrCode;
         }
 
         if(ha->dwFlags & MPQ_FLAG_ATTRIBUTES_NEW)
         {
-            nError = SAttrFileSaveToMpq(ha);
-            if(nError != ERROR_SUCCESS)
-                nResultError = nError;
+            dwErrCode = SAttrFileSaveToMpq(ha);
+            if(dwErrCode != ERROR_SUCCESS)
+                dwResultError = dwErrCode;
         }
 
         // Save HET table, BET table, hash table, block table, hi-block table
@@ -548,16 +605,16 @@ bool WINAPI SFileFlushArchive(HANDLE hMpq)
                 RebuildHetTable(ha);
 
             // Save all MPQ tables first
-            nError = SaveMPQTables(ha);
-            if(nError != ERROR_SUCCESS)
-                nResultError = nError;
+            dwErrCode = SaveMPQTables(ha);
+            if(dwErrCode != ERROR_SUCCESS)
+                dwResultError = dwErrCode;
 
             // If the archive has weak signature, we need to finish it
             if(ha->dwFileFlags3 != 0)
             {
-                nError = SSignFileFinish(ha);
-                if(nError != ERROR_SUCCESS)
-                    nResultError = nError;
+                dwErrCode = SSignFileFinish(ha);
+                if(dwErrCode != ERROR_SUCCESS)
+                    dwResultError = dwErrCode;
             }
         }
 
@@ -566,9 +623,9 @@ bool WINAPI SFileFlushArchive(HANDLE hMpq)
     }
 
     // Return the error
-    if(nResultError != ERROR_SUCCESS)
-        SetLastError(nResultError);
-    return (nResultError == ERROR_SUCCESS);
+    if(dwResultError != ERROR_SUCCESS)
+        SetLastError(dwResultError);
+    return (dwResultError == ERROR_SUCCESS);
 }
 
 //-----------------------------------------------------------------------------
