@@ -82,7 +82,7 @@ function Briefing(title, objs, bg, text, voices)
   local voice = 0
   local channel = -1
 
-  menu:addContinueButton(_("~!Continue"), "c", 455 * Video.Width / 640, 440 * Video.Height / 480,
+  local ctbtn = menu:addContinueButton(_("~!Continue"), "c", 455 * Video.Width / 640, 440 * Video.Height / 480,
     function()
       if (channel ~= -1) then
         voice = table.getn(voices)
@@ -91,7 +91,7 @@ function Briefing(title, objs, bg, text, voices)
       menu:stop()
       StopMusic()
     end)
-
+  ctbtn:requestFocus()
 
   function PlayNextVoice()
     voice = voice + 1
@@ -159,18 +159,63 @@ end
 
 function CreatePictureStep(bg, sound, title, text)
   return function()
-    SetPlayerData(GetThisPlayer(), "RaceName", CurrentCampaignRace)
-    wargus.playlist = {}
-    PlayMusic(sound)
-    local menu = WarMenu(nil, bg, true)
-    local offx = (Video.Width - 640) / 2
-    local offy  = (Video.Height - 480) / 2
-    menu:addLabel(title, offx + 320, offy + 240 - 67, Fonts["small-title"], true)
-    menu:addLabel(text, offx + 320, offy + 240 - 25, Fonts["large-title"], true)
-    menu:addHalfButton(_("~!Continue"), "c", 455 * Video.Width / 640, 440 * Video.Height / 480,
-      function()  menu:stop(1) end)
-    menu:run()
-    GameResult = GameVictory
+     SetPlayerData(GetThisPlayer(), "RaceName", CurrentCampaignRace)
+     wargus.playlist = {}
+     PlayMusic(sound)
+     local menu = WarMenu(nil, bg, true)
+     local offx = (Video.Width - 640) / 2
+     local offy  = (Video.Height - 480) / 2
+
+     local whiteLabel = menu:addLabel(title, offx + 320, offy + 240 - 67, Fonts["small-title"], true)
+     local whiteLabel2 = menu:addLabel(text, offx + 320, offy + 240 - 25, Fonts["large-title"], true)
+     whiteLabel:setVisible(false)
+     whiteLabel2:setVisible(false)
+
+     local blackScreen = Container()
+     blackScreen:setSize(Video.Width, Video.Height)
+     blackScreen:setBaseColor(Color(0, 0, 0, 255))
+     blackScreen:setOpaque(true)
+     menu:add(blackScreen, 0, 0)
+
+     local redLabel = Label("~full-red~" .. title)
+     redLabel:setFont(Fonts["small-title"])
+     redLabel:adjustSize()
+     blackScreen:add(redLabel, offx + 320 - redLabel:getWidth() / 2, offy + 240 - 67)
+     local redLabel2 = Label("~full-red~" .. text)
+     redLabel2:setFont(Fonts["large-title"])
+     redLabel2:adjustSize()
+     blackScreen:add(redLabel2, offx + 320 - redLabel2:getWidth() / 2, offy + 240 - 25)
+
+     local alpha = 255
+     local time = 0
+     local function fadeBlack()
+        time = time + 1
+        if alpha >= 0 and time > 30 then
+           blackScreen:setBaseColor(Color(0, 0, 0, alpha))
+           redLabel:setCaption("~full-red~" .. title) -- simple way to get container dirty
+           alpha = alpha - 20
+           if alpha < 0 then
+              alpha = 0
+           end
+        end
+        if time > 90 then
+           whiteLabel:setVisible(true)
+           whiteLabel2:setVisible(true)
+           redLabel:setVisible(false)
+           redLabel2:setVisible(false)
+        end
+        if time > 200 then
+           menu:stop(1)
+        end
+     end
+     local listener = LuaActionListener(fadeBlack)
+     menu:addLogicCallback(listener)
+     
+     local btn = menu:addHalfButton(_("~!Continue"), "c", 455 * Video.Width / 640, 440 * Video.Height / 480,
+                                    function()  menu:stop(1) end)
+     btn:requestFocus()
+     menu:run()
+     GameResult = GameVictory
   end
 end
 
@@ -275,35 +320,24 @@ function RunCampaignSubmenu(campaign)
 	missionList[i] = CampaignButtonTitle(i)
   end
   local missionListBox = menu:addImageListBox(offx + 80, offy + 100, 480, 250, missionList)
+  missionListBox:setSelected(#missionList - 1)
   menu:addLabel(_("~<AI Difficulty:~>"), offx + 80, offy + 214 + (36 * 4), Fonts["game"], false)
   difficulty = menu:addDropDown(difficulty_types, offx + 200, offy + 212 + (36 * 4),
     function(dd) end)
   difficulty:setSize(170, 20)
   difficulty:setSelected(1)
-  
-  local goButton = menu:addFullButton(_("~!Play mission"), "p", offx + 208, offy + 212 + (36 * 5),  
+
+  local goButton = menu:addFullButton(_("~!Start mission"), "s", offx + 208, offy + 212 + (36 * 5),  
 			function() 
 				GameSettings.Difficulty = difficulty:getSelected() + 1
 				wc2.preferences.LastDifficulty = GameSettings.Difficulty
 				SavePreferences()
 				return CampaignButtonFunction(campaign, missionListBox:getSelected() + 1, menu) 
 			end)
-  local function UpdateGo()
-	if missionListBox:getSelected() ~= -1 then
-		 goButton:setVisible(true)
-	else
-		goButton:setVisible(false)
-	end
-  end
-  goButton:setVisible(false)
-  local listener = LuaActionListener(UpdateGo)
-  menu:addLogicCallback(listener)
-  menu:addFullButton(_("~!Previous Menu"), "p", offx + 208, offy + 212 + (36 * 6),
+  menu:addFullButton(_("Previous Menu (~<Esc~>)"), "escape", offx + 208, offy + 212 + (36 * 6),
     function()  menu:stop(1); RunSinglePlayerTypeMenu(); currentCampaign = nil; currentState = nil; end)
 
-  if (wargus.tales == false) then
-    menu:addLabel(wargus.Name .. " V" .. wargus.Version .. ", " .. wargus.Copyright, offx + 320, (Video.Height - 90) + 18*4, Fonts["small"]) -- Copyright information.
-  end
+  menu:addLabel(wargus.Name .. " V" .. wargus.Version .. ", " .. wargus.Copyright, offx + 320, (Video.Height - 90) + 18*4, Fonts["small"]) -- Copyright information.
   
   menu:run()
 
