@@ -27,31 +27,29 @@
 
 */
 
+#include "wargus.h"
+
 #define GAME_NAME "Wargus"
-#define GAME_CD "Warcraft II DOS REZDAT.WAR or BNE INSTALL.MPQ/INSTALL.EXE file"
-#define GAME_CD_FILE_PATTERNS "REZDAT.WAR", "rezdat.war", "War Resources", "INSTALL.EXE", "Install.exe", "Install.mpq", "INSTALL.MPQ"
+#define GAME_CD "Warcraft II DOS REZDAT.WAR, BNE INSTALL.MPQ/INSTALL.EXE file, or GoG installer exe"
+#define GAME_CD_FILE_PATTERNS "REZDAT.WAR", "rezdat.war", "War Resources", "INSTALL.EXE", "Install.exe", "Install.mpq", "INSTALL.MPQ", "install.exe", "install.mpq", "setup*.exe"
 #define GAME "wargus"
 #define EXTRACTOR_TOOL "wartool"
-#define EXTRACTOR_ARGS "-v -r"
+#define EXTRACTOR_ARGS {"-v", "-r", NULL}
 #define CHECK_EXTRACTED_VERSION 1
 
+#define EXTRACTION_FILES REEXTRACT_MARKER_FILE
+
 #define __wargus_contrib__ "campaigns", "campaigns", \
                            "contrib", "graphics/ui", \
                            "maps", "maps", \
                            "shaders", "shaders", \
-                           "scripts", "scripts", \
-                           ":optional:", \
-                           "music/TimGM6mb.sf2", "music/TimGM6mb.sf2"
+                           "scripts", "scripts"
+                           // ":optional:", \
+                           // "music/TimGM6mb.sf2", "music/TimGM6mb.sf2"
 
-#ifdef WIN32
 #define CONTRIB_DIRECTORIES { __wargus_contrib__, NULL }
-#else
-// for convenience during development, we also try to copy the system
-// soundfont to the data directory on linux
-#define CONTRIB_DIRECTORIES { __wargus_contrib__, "/usr/share/sounds/sf2/TimGM6mb.sf2", "music/TimGM6mb.sf2", NULL }
-#endif
 #define GAME_SHOULD_EXTRACT_AGAIN (tinyfd_messageBox("Extract more?", \
-                                                     "Extract from an additional expansion CD?", \
+                                                     "Extract from the additional DOS expansion CD?", \
                                                      "yesno",           \
                                                      "question",        \
                                                      1))
@@ -64,7 +62,4 @@ const char* SRC_PATH() { return __FILE__; }
 #define TITLE_PNG "%s/graphics/ui/title.png"
 #endif
 
-#undef DATA_PATH
-#define DATA_PATH "invalid"
-
 #include <stratagus-game-launcher.h>
